@@ -8,6 +8,7 @@ import django
 # from django.core.validators import ValidationError
 from django.utils import importlib
 from django.utils.functional import Promise
+from django.conf import settings
 
 try:
     from django.utils.encoding import force_bytes
@@ -57,12 +58,24 @@ else:
         memoryview = buffer
 
 
-def hack_engine(engine_module):
-    creation = importlib.import_module(engine_module + '.creation')
+def hack_engine(engine_module, ):
+    try:
+        creation = importlib.import_module(engine_module + '.creation')
+    except ImportError:
+        # try to fallback to the .base
+        creation = importlib.import_module(engine_module + '.base')
+
     byte_type_mapping = {
-        'django.db.backends.sqlite3' : 'BLOB',
+        'django.db.backends.sqlite3': 'BLOB',
+        'django.db.backends.oracle': 'BLOB',
+        'django.db.backends.postgresql_psycopg2': 'bytea',
+        'django.db.backends.mysql': 'longblob',
     }
 
+    # a place in settings to define your own type mappings for custom backends
+    EXTRA_TYPE_MAPPING = getattr(settings, 'BINARYFIELD_EXTRA_TYPE_MAPPING', {})
+    byte_type_mapping.update(EXTRA_TYPE_MAPPING)
+
     creation.DatabaseCreation.data_types['BinaryField'] = byte_type_mapping[engine_module]
 
 
